;
;   Module name      :	TestIniUtil.au3
;
;   Description      :	None
;
;   Parameters       :	None
;   Notes - usage    :	None
;


;--- Global directives -----------------------------------------------------------------------------



Opt("TrayIconDebug", 1)

Opt("MustDeclareVars", 1)
Opt("GUICloseOnESC", 0)



;--- Include files ---------------------------------------------------------------------------------



#include <DebugUtil.au3>
#include "IniUtil.au3"



;--- Global constants ------------------------------------------------------------------------------



;--- Global variables ------------------------------------------------------------------------------



global $Module_prefix = "IU"



;--- Functions code --------------------------------------------------------------------------------



func PrintFooter()
;---
; Prints the ending string.
;
; ret	nothing
;---
	DURawPrint("--- End of tests (" & @HOUR & ":" & @MIN & ":" & @SEC & ") ---" & @CRLF)
endfunc



func PrintHeader()
;---
; Sets the debug Notepad window and prints the title.
;
; ret	nothing
;---
	DUInit("Test file for " & eval($Module_prefix & "_FILE_NAME") & " " & eval ($Module_prefix & "_MODULE_VER"))
	DURawPrint("--- Start of tests (" & @HOUR & ":" & @MIN & ":" & @SEC & ") ---")
endfunc



;--- Main code -------------------------------------------------------------------------------------



PrintHeader()

; Test code for IniUtil.au3 starts here.

#cs
DUPrint(IUInit(), @error)							; = "TestIniUtil.ini", $IU_NOT_FOUND
DUPrint(IUInit("", ""), @error)						; = "TestIniUtil.ini", $IU_NOT_FOUND
DUPrint(IUInit("dummy", ""), @error)				; = "dummy", $IU_NOT_FOUND
DUPrint(IUInit("dummy.foo", ""), @error)			; = "dummy.ini", $IU_NOT_FOUND
DUPrint(IUInit("dummy.foo.bar", ""), @error)		; = "dummy.foo.ini", $IU_NOT_FOUND

DUPrint(IUInit("win.foo", ""), @error)				; = "C:\WINDOWS\win.ini", $IU_NO_ERROR
DUPrint(IUInit("win.ini", ""), @error)				; = "C:\WINDOWS\win.ini", $IU_NO_ERROR

DUPrint(IUInit("C:\WINDOWS\win.ini", ""), @error)	; = "C:\WINDOWS\win.ini", $IU_NO_ERROR
DUPrint(IUInit("C:\WINDOWS\foo.ini", ""), @error)	; = "C:\WINDOWS\foo.ini", $IU_NOT_FOUND

DUPrint(IUInit("win.foo", "C:\"), @error)			; = "win.ini", $IU_NOT_FOUND
DUPrint(IUInit("win.foo", @WindowsDir), @error)		; = "C:\WINDOWS\win.ini", $IU_NO_ERROR

DUPrint(IUInit("boot.foo", "C:\"), @error)			; = "C:\boot.ini", $IU_NO_ERROR
DUPrint(IUInit("boot.foo", @WindowsDir), @error)	; = "boot.ini", $IU_NOT_FOUND
#ce

#cs
; To run this test, ".\TestIniUtil2.ini" must exist with these contents:
; [Main]
; VarA=1
; [Another]
; VarC=2
global $t2_a = -1, $t2_b = -2, $t2_c = -3, $t2_d = -4, $t2_e = -5
global $t2_def1[2] = [1, 2]
global $t2_def2[2][2] = [[1, 2], [3, 4]]
global $t2_def3[2][4] = [ _
		["Main",	"VarA",	"t2_a",		9], _
		["Main",	"VarB",	"t2_b",		8] _
		]
global $t2_def4[2][4] = [ _
		["Main",	"VarA",	"t2_a",		9], _
		["Main",	"VarB",	"t2_b2",	8] _
		]
global $t2_def5[5][4] = [ _
		["Main",	"VarA",	"t2_a",		9], _
		["Main",	"VarB",	"t2_b",		8], _
		["Another",	"VarC",	"t2_c",		7], _
		["Another",	"VarD",	"t2_d",		6], _
		["Another",	"VarE",	"t2_e",		default] _
		]
DUPrint(IUReadVars(".\TestIniUtil2.ini", $t2_def1), @error)					; = ["InnerDim", 0], $IU_INVALID_DEF
DUPrint(IUReadVars(".\TestIniUtil2.ini", $t2_def2), @error)					; = ["InnerDim", 2], $IU_INVALID_DEF
DUPrint(IUReadVars(".\TestIniUtil2.ini", $t2_def3), $t2_a, $t2_b, @error)	; = 1, 1, 8, $IU_NO_ERROR
$t2_a = -1
$t2_b = -2
DUPrint(IUReadVars(".\TestIniUtil2.ini", $t2_def4), $t2_a, @error)			; = ["t2_b2", 8], 1, $IU_UNDEF_VAR
$t2_a = -1
DUPrint(IUReadVars(".\TestIniUtil2.ini", $t2_def5), $t2_a, $t2_b, $t2_c, $t2_d, $t2_e, @error)
													; = ["Another", "VarE"], 1, 8, 2, 6, -5, $IU_VAR_NOT_FOUND
#ce

#cs
; To run this test, ".\TestIniUtil2.ini" and "C:\boot.ini" must exist; "C:\boot.ini" must be ReadOnly.
global $t3_a = -1, $t3_b = -2, $t3_c = -3
global $t3_def1[2] = [1, 2]
global $t3_def2[2][2] = [[1, 2], [3, 4]]
global $t3_def3[2][3] = [ _
		["Main",		"Var1",		"t3_a"], _
		["Main",		"Var2",		"t3_b"] _
		]
global $t3_def4[2][3] = [ _
		["Another",		"Var3",		"t3_c"], _
		["Another",		"Var4",		"t3_b2"] _
		]
global $t3_def5[1][3] = [ _
		["boot loader",	"timeout",	"t3_a"] _
		]
DUPrint(IUWriteVars(".\TestIniUtil2.ini", $t3_def1), @error)	; = ["InnerDim", 0], $IU_INVALID_DEF
DUPrint(IUWriteVars(".\TestIniUtil2.ini", $t3_def2), @error)	; = ["InnerDim", 2], $IU_INVALID_DEF
DUPrint(IUWriteVars(".\TestIniUtil2.ini", $t3_def3), @error)	; = 1, $IU_NO_ERROR, [Main]: Var1=-1 Var2=-2
DUPrint(IUWriteVars(".\TestIniUtil2.ini", $t3_def4), @error)	; = ["t3_b2", ""], $IU_UNDEF_VAR, [Another]: Var3=-3
DUPrint(IUWriteVars("C:\boot.ini", $t3_def5), @error)			; = ["boot loader", "timeout"], $IU_WRITE_FAILED
#ce

#cs
; To run this test, ".\TestIniUtil2.ini" must exist with these contents:
; [ArraySec]
; VarA=1
; VarC=3
; VarB=2
global $t4_a = -1, $t4_b = -2, $t4_c = -3, $t4_d = -4
global $t4_def1[2] = [1, 2]
global $t4_def2[2][2] = [[1, 2], [3, 4]]
global $t4_def3[1][4] = [["ArraySec", "",			"t4_a", 9]]
global $t4_def4[1][4] = [["ArraySec", "List",		"t4_a", 9]]
global $t4_def5[1][4] = [["ArraySec", "Foo=VarA",	"t4_a", 9]]
global $t4_def6[1][4] = [["ArraySec", "List=VarA",	"t4_qq", 9]]
global $t4_def7[4][4] = [ _
		["ArraySec",	"List=VarA=VarB=VarC=VarD",	"t4_a",	9], _
		["ArraySec",	"List=VarA",				"t4_b",	8], _
		["ArraySec",	"List=VorA=VarB=VorC",		"t4_c",	7], _
		["ArraySec",	"List=VorA",				"t4_d",	6] _
		]
global $t4_def8[2][4] = [ _
		["ArraySec",	"List=VarB=VarD=VarA=VarC",	"t4_a",	9], _
		["ArraySec",	"List=VarC=VarC=VarA=VarD",	"t4_b",	default] _
		]
DUPrint(IUReadArrays(".\TestIniUtil2.ini", $t4_def1), @error)		; = ["InnerDim", 0], $IU_INVALID_DEF
DUPrint(IUReadArrays(".\TestIniUtil2.ini", $t4_def2), @error)		; = ["InnerDim", 2], $IU_INVALID_DEF
DUPrint(IUReadArrays(".\TestIniUtil2.ini", $t4_def3), @error)		; = ["TooShort", ""], $IU_INVALID_DEF
DUPrint(IUReadArrays(".\TestIniUtil2.ini", $t4_def4), @error)		; = ["TooShort", "List"], $IU_INVALID_DEF
DUPrint(IUReadArrays(".\TestIniUtil2.ini", $t4_def5), @error)		; = ["InvOper", "foo"], $IU_INVALID_DEF
DUPrint(IUReadArrays(".\TestIniUtil2.ini", $t4_def6), @error)		; = ["t4_qq", ""], $IU_UNDEF_VAR
DUPrint(IUReadArrays(".\TestIniUtil2.ini", $t4_def7), $t4_a, $t4_b, $t4_c, $t4_d, @error)
														; = 1, [1, 2, 3, 9], [1], [7, 2, 7], [6], $IU_NO_ERROR
$t4_a = -1
$t4_b = -2
DUPrint(IUReadArrays(".\TestIniUtil2.ini", $t4_def8), $t4_a, $t4_b, @error)
												; = ["ArraySec", "VarD"], [2, 9, 1, 3], -2, $IU_VAR_NOT_FOUND
#ce

#cs
; To run this test, ".\TestIniUtil2.ini" must exist with these contents:
; [ArraySec2]
; Var01=01
; Var02=02
; Var04=04
global $t5_a = -1, $t5_b = -2
global $t5_def1[2][4] = [["ArraySec2", "Step=Var=2=1",		"t5_a", 9]]
global $t5_def2[2][4] = [["ArraySec2", "Step=Var=2=1=5=99",	"t5_a", 9]]
global $t5_def3[2][4] = [ _
		["ArraySec2",	"Step=Var=2=1=5",	"t5_a",	9], _
		["ArraySec2",	"Step=Var0=1=1=4",	"t5_b",	8] _
		]
global $t5_def4[2][4] = [ _
		["ArraySec2",	"Step=Var=2=2=3",	"t5_a",	7], _
		["ArraySec2",	"Step=Var0=1=1=4",	"t5_b",	default] _
		]
DUPrint(IUReadArrays(".\TestIniUtil2.ini", $t5_def1), @error)
													; = ["InvStruct", "Step=Var=2=1"], $IU_INVALID_DEF
DUPrint(IUReadArrays(".\TestIniUtil2.ini", $t5_def2), @error)
													; = ["InvStruct", "Step=Var=2=1=5=99"], $IU_INVALID_DEF
DUPrint(IUReadArrays(".\TestIniUtil2.ini", $t5_def3), $t5_a, $t5_b, @error)
													; = 1, [01, 02, 9, 04, 9], [01, 02, 8, 04], $IU_NO_ERROR
$t5_a = -1
$t5_b = -2
DUPrint(IUReadArrays(".\TestIniUtil2.ini", $t5_def4), $t5_a, $t5_b, @error)
													; = ["ArraySec2", "Var03"], [02, 7], -2, $IU_VAR_NOT_FOUND
#ce

#cs
; To run this test, ".\TestIniUtil2.ini" and "C:\boot.ini" must exist; "C:\boot.ini" must be ReadOnly.
global $t6_a[1] = [-1], $t6_b[2] = [2, -2], $t6_c[3] = [3, 0, -3], $t6_d = -4
global $t6_def01[2] = [1, 2]
global $t6_def02[2][2] = [[1, 2], [3, 4]]
global $t6_def03[1][3] = [["ArraySec3", "",				"t6_a"]]
global $t6_def04[1][3] = [["ArraySec3", "List",			"t6_a"]]
global $t6_def05[1][3] = [["ArraySec3", "Foo=VarA",		"t6_a"]]
global $t6_def06[1][3] = [["ArraySec3", "List=VarA",	"qq"]]
global $t6_def07[1][3] = [["ArraySec3", "List=VarA",	"t6_a"]]
global $t6_def08[1][3] = [["ArraySec3", "List=VarA",	"t6_d"]]
global $t6_def09[1][3] = [["ArraySec3", "List=VarA",	"t6_def02"]]
global $t6_def10[2][3] = [ _
		["ArraySec3",	"List=VarA",			"t6_a"], _
		["ArraySec3",	"List=VarB=VarC=VarD",	"t6_c"] _
		]
global $t6_def11[2][3] = [ _
		["ArraySec3",	"List=VarE=VarF",		"t6_c"], _
		["ArraySec3",	"List=VarG=VarH=VarI",	"t6_b"] _
		]
DUPrint(IUWriteArrays(".\TestIniUtil2.ini", $t6_def01), @error)	; = ["InnerDim", 0], $IU_INVALID_DEF
DUPrint(IUWriteArrays(".\TestIniUtil2.ini", $t6_def02), @error)	; = ["InnerDim", 2], $IU_INVALID_DEF
DUPrint(IUWriteArrays(".\TestIniUtil2.ini", $t6_def03), @error)	; = ["TooShort", ""], $IU_INVALID_DEF
DUPrint(IUWriteArrays(".\TestIniUtil2.ini", $t6_def04), @error)	; = ["TooShort", "List"], $IU_INVALID_DEF
DUPrint(IUWriteArrays(".\TestIniUtil2.ini", $t6_def05), @error)	; = ["InvOper", "foo"], $IU_INVALID_DEF
DUPrint(IUWriteArrays(".\TestIniUtil2.ini", $t6_def06), @error)	; = ["qq", ""], $IU_UNDEF_VAR
DUPrint(IUWriteArrays("C:\boot.ini", $t6_def07), @error)		; = ["ArraySec3", "VarA"], $IU_WRITE_FAILED
DUPrint(IUWriteArrays(".\TestIniUtil2.ini", $t6_def08), @error)	; = ["InvArray", "t6_d"], $IU_INVALID_DEF
DUPrint(IUWriteArrays(".\TestIniUtil2.ini", $t6_def09), @error)	; = ["InvArray", "t6_def02"], $IU_INVALID_DEF
DUPrint(IUWriteArrays(".\TestIniUtil2.ini", $t6_def10), @error)
										; = 1, $IU_NO_ERROR, [ArraySec3]: VarA=-1 VarB=3 VarC=0 VarD=-3
DUPrint(IUWriteArrays(".\TestIniUtil2.ini", $t6_def11), @error)
										; = ["InvArray", "t6_b"], $IU_INVALID_DEF, [ArraySec3]: VarE=3 VarF=0
#ce

#cs
; To run this test, ".\TestIniUtil2.ini" and "C:\boot.ini" must exist; "C:\boot.ini" must be ReadOnly.
global $t7_a[1] = [-1], $t7_b[2] = [2, -2], $t7_c[3] = [3, 0, -3]
global $t7_def1[2][3] = [["ArraySec4", "Step=Var=2=1", "t7_a"]]
global $t7_def2[2][3] = [["ArraySec4", "Step=Var=2=1=5=99", "t7_a"]]
global $t7_def3[1][3] = [["ArraySec4", "Step=Var=2=1=2", "t7_c"]]
global $t7_def4[2][3] = [ _
		["ArraySec4",	"Step=Var=2=1=3",	"t7_c"], _
		["ArraySec4",	"Step=Var2=1=2=3",	"t7_b"] _
		]
global $t7_def5[2][3] = [ _
		["ArraySec4",	"Step=Var=3=9=10",	"t7_c"], _
		["ArraySec4",	"Step=Var9=1=1=4",	"t7_a"] _
		]
DUPrint(IUWriteArrays(".\TestIniUtil2.ini", $t7_def1), @error)
													; = ["InvStruct", "Step=Var=2=1"], $IU_INVALID_DEF
DUPrint(IUWriteArrays(".\TestIniUtil2.ini", $t7_def2), @error)
													; = ["InvStruct", "Step=Var=2=1=5=99"], $IU_INVALID_DEF
DUPrint(IUWriteArrays("C:\boot.ini", $t7_def3), @error)
													; = ["ArraySec4", "Var01"], $IU_WRITE_FAILED
DUPrint(IUWriteArrays(".\TestIniUtil2.ini", $t7_def4), @error)
									; = 1, $IU_NO_ERROR, [ArraySec4]: Var01=3 Var02=0 Var03=-3 Var22=2 Var23=-2
DUPrint(IUWriteArrays(".\TestIniUtil2.ini", $t7_def5), @error)
									; = ["InvArray", "t7_a"], $IU_INVALID_DEF, [ArraySec4]: Var009=3 Var010=0
#ce

#cs
; To run this test, ".\TestIniUtil2.ini" must exist with these contents:
; [ArraySec]
; VarF=1
; VarF=3
; VarF=2
; VarG=2
; VarG=1
global $t8_a = -1, $t8_b = -2, $t8_c = -3
global $t8_def1[1][4] = [["ArraySec",	"Group",		"t8_a", 9]]
global $t8_def2[1][4] = [["ArraySc",	"Group=VarF",	"t8_a", default]]
global $t8_def3[1][4] = [["ArraySc",	"Group=VarF",	"t8_a", 9]]
global $t8_def4[1][4] = [["ArraySec",	"Group=VarQ",	"t8_a", default]]
global $t8_def5[1][4] = [["ArraySec",	"Group=VarQ",	"t8_a", 8]]
global $t8_def6[3][4] = [ _
		["ArraySec",	"Group=VarQ",	"t8_a",	7], _
		["ArraySec",	"Group=VarF",	"t8_b",	6], _
		["ArraySec",	"Group=VarG",	"t8_c",	5] _
		]
DUPrint(IUReadArrays(".\TestIniUtil2.ini", $t8_def1), @error)		; = ["TooShort", "Group"], $IU_INVALID_DEF
DUPrint(IUReadArrays(".\TestIniUtil2.ini", $t8_def2), @error)		; = ["ArraySc", "*"], $IU_VAR_NOT_FOUND
DUPrint(IUReadArrays(".\TestIniUtil2.ini", $t8_def3), $t8_a, @error); = 1, [9], $IU_NO_ERROR
DUPrint(IUReadArrays(".\TestIniUtil2.ini", $t8_def4), @error)		; = ["ArraySec", "VarQ"], $IU_VAR_NOT_FOUND
DUPrint(IUReadArrays(".\TestIniUtil2.ini", $t8_def5), $t8_a, @error); = 1, [8], $IU_NO_ERROR
DUPrint(IUReadArrays(".\TestIniUtil2.ini", $t8_def6), $t8_a, $t8_b, $t8_c, @error)
																	; = 1, [7], [1, 3, 2], [2, 1], $IU_NO_ERROR
#ce

; Test code for IniUtil.au3 ends here.

PrintFooter()
